<template>
  <!--支持全屏缩放-->
  <a-modal :visible="visible" :title="title" switchFullscreen @ok="handleSubmit" @cancel="close" style="top:50px"
    cancelText="关闭" :width="1600">
    <a-card :bordered="false">
      <div class="table-page-search-wrapper">
        <a-form layout="inline" @keyup.enter.native="searchQuery">
          <a-row :gutter="24">
            <a-col :md="5" :sm="4">
              <a-form-item label="设备编码">
                <a-input placeholder="请输入设备编码" v-model="queryParam.num" />
              </a-form-item>
            </a-col>
            <a-col :md="5" :sm="4">
              <a-form-item label="设备名称">
                <a-input placeholder="请输入设备名称" v-model="queryParam.name" />
              </a-form-item>
            </a-col>
            <a-col :md="4" :sm="3">
              <a-form-item label="设备状态">
                <a-select v-model="queryParam.equipmentStatus" :options="equipmentStatusList" placeholder="请选择设备状态" />
              </a-form-item>
            </a-col>
            <a-col :md="4" :sm="3">
              <a-form-item label="技术状态">
                <a-select v-model="queryParam.technologyStatus" :options="technologyStatusList" placeholder="请选择设备状态" />
              </a-form-item>
            </a-col>

            <a-col :md="3">
              <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
                <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
                <a-button @click="searchReset" icon="reload" style="margin-left: 10px">重置</a-button>
              </span>
            </a-col>
          </a-row>
        </a-form>
      </div>
      <a-row :gutter="24">
        <a-col :md="16" :sm="12">
          <a-table ref="table" :scroll="{ x: true, y: true }" size="middle" rowKey="id" bordered :columns="columns"
            :dataSource="dataSource" :pagination="false" :rowSelection="rowSelection" :loading="loading"
            @change="handleTableChange">
            <template slot="equipmentPhoto" slot-scope="text,record">
              <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
              <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt=""
                style="max-width:80px;font-size: 12px;font-style: italic;" />
            </template>
          </a-table>
        </a-col>
        <a-col :md="7" :sm="5">
          <a-table ref="table" :scroll="{ y: true }" :pagination="false" size="middle" rowKey="id" bordered
            :columns="selectColumns" :dataSource="selectSource" :loading="loading">
            <span slot="action" slot-scope="text, record">
              <a @click="deleteSelectRowkey(record)">删除</a>
            </span>
          </a-table>
        </a-col>
      </a-row>

    </a-card>
  </a-modal>
</template>
  
<script>
import { filterObj } from '@/utils/util'
import { getAction } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { ajaxGetDictItems, getDictItemsFromCache } from '@/api/api'
export default {
  name: 'EquipmentSelectModal',
  mixins: [JeecgListMixin],
  components: {},
  props: {
    equipmentStatus: {
      type: Array,
      default: () => []
    },
    technologyStatus: {
      type: Array,
      default: () => []
    },
  },
  data() {
    return {
      queryParam: {},
      columns: [
        {
          title: '设备编码',
          align: 'center',
          dataIndex: 'num',
          width: 120,
          ellipsis: true
        },
        {
          title: '设备名称',
          align: 'center',
          dataIndex: 'name',
          width: 120,
          ellipsis: true
        },
        {
          title: '资产编码',
          align: 'center',
          dataIndex: 'assetNumber',
          width: 120
        },

        {
          title: '特种设备',
          align: 'center',
          dataIndex: 'specificEquipment_dictText',
          width: 120,
          ellipsis: true
        },

        {
          title: '设备型号',
          align: 'center',
          dataIndex: 'model',
          width: 120,
          ellipsis: true
        },
        {
          title: '设备规格',
          align: 'center',
          dataIndex: 'specification',
          width: 120,
          ellipsis: true
        },
        {
          title: '设备状态',
          align: 'center',
          dataIndex: 'equipmentStatus_dictText',
          width: 120,
          ellipsis: true
        },
        {
          title: '技术状态',
          align: 'center',
          dataIndex: 'technologyStatus_dictText',
          width: 120,
          ellipsis: true
        },
        {
          title: '设备图片',
          align: 'center',
          dataIndex: 'equipmentPhoto',
          scopedSlots: { customRender: 'equipmentPhoto' },
          width: 120,
          ellipsis: true
        }
      ],
      selectColumns: [
        {
          title: '设备编码',
          align: 'center',
          dataIndex: 'num',
          width: 120,
          ellipsis: true
        },
        {
          title: '设备名称',
          align: 'center',
          dataIndex: 'name',
          width: 100,
          ellipsis: true
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          scopedSlots: { customRender: 'action' },
        }
      ],
      selectedRowKeys: [],
      oldSelectRows: [],
      scrollTrigger: {},
      dataSource: [],
      selectSource: [],
      selectionRows: [],
      title: '选择设备',
      ipagination: {
        current: 1,
        pageSize: 999999999,
        pageSizeOptions: ['5', '10', '30', '50', '100'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      isorter: {
        column: 'num',
        order: 'desc'
      },
      visible: false,
      loading: false,
      url: {
        list: '/eam/equipment/list'
      },
      equipmentStatusList: [],
      technologyStatusList: []
    }
  },
  computed: {
    rowSelection() {
      const { selectedRowKeys } = this;
      return {
        type: 'checkbox',
        onChange: this.onSelectChange,
        getCheckboxProps: record => ({
          props: {
            disabled: record.distable
          }
        }),
        selectedRowKeys
      }
    }
  },
  created() {
    this.initSelection_searchList()
  },
  methods: {
    checkAdult(item, list) {
      return !list.includes(item.value)
    },
    initSelection_searchList() {
      // 初始设备状态 移除不需要的选项
      this.equipmentStatusList = this.initDictData('equipment_status')
      if (this.equipmentStatus && this.equipmentStatus.length > 0) {
        this.equipmentStatusList = this.equipmentStatusList.filter(res => this.checkAdult(res, this.equipmentStatus))
      }
      // 初始技术状态 移除不需要的选项
      this.technologyStatusList = this.initDictData('technology_status')
      if (this.equipmentStatus && this.equipmentStatus.length > 0) {
        this.technologyStatusList = this.technologyStatusList.filter(res => this.checkAdult(res, this.technologyStatus))
      }

    },
    // equipment_status  technology_status
    initDictData(dictCode) {
      //优先从缓存中读取字典配置
      if (getDictItemsFromCache(dictCode)) {
        return getDictItemsFromCache(dictCode);

      }
      //根据字典Code, 初始化字典数组
      ajaxGetDictItems(dictCode, null).then((res) => {
        if (res.success) {
          return res.result;
        }
      })
    },
    deleteSelectRowkey(key) {
      this.selectedRowKeys = this.selectedRowKeys.filter(item => item != key.id)
      this.selectSource = this.selectSource.filter(item => item != key)
    },
    onSelectChange(selectedRowKeys, selectedRows) {
      this.selectedRowKeys = selectedRowKeys;
      if (selectedRowKeys.length === selectedRows.length) {
        this.selectedRows = selectedRows;
      } else {
        this.selectedRows = selectedRowKeys.map(key => (
          this.selectedRows.find(row => row.id === key) || selectedRows.find(row => row.id === key)//必在两者之中
        ));
      }
      this.selectSource = [...this.selectedRows]
    },

    async loadData(arg) {
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.loading = true
      let params = this.getQueryParams()//查询条件
      await getAction(this.url.list, params).then((res) => {
        if (res.success) {
          for (let i = 0; i < res.result.records.length; i++) {
            if (this.oldSelectRows.indexOf(res.result.records[i].id) > -1) {
              this.selectSource.push(res.result.records[i])
            }
            // if (this.oldSelectRows.indexOf(res.result.records[i].id) > -1) {
            //     res.result.records[i].distable = true
            //   } else {
            //     res.result.records[i].distable = false
            //   }
          }
          this.selectSource = [... new Set(this.selectSource)]
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })
    },

    showModals(oldSelectRows, selectTableData) {
      this.oldSelectRows = oldSelectRows
      this.selectedRowKeys = oldSelectRows
      // this.selectedRows  = selectTableData
      this.visible = true
      this.loadData(1)
    },
    getQueryParams() {
      let param = Object.assign({}, this.queryParam, this.isorter)
      param.field = this.getQueryField()
      param.pageNo = this.ipagination.current
      param.pageSize = this.ipagination.pageSize
      return filterObj(param)
    },
    //查询条件处理
    getQueryField() {
      let str = 'id,'
      for (let a = 0; a < this.columns.length; a++) {
        str += ',' + this.columns[a].dataIndex
      }
      return str
    },
    searchReset(num) {
      this.queryParam = []
      if (num !== 0) {
        this.loadData(1)
      }
      this.selectborrowIds = []
    },
    close() {
      this.searchReset(0)
      this.selectedRowKeys = []
      this.selectSource = []
      this.visible = false
    },
    handleTableChange(pagination, filters, sorter) {
      //TODO 筛选
      if (Object.keys(sorter).length > 0) {
        this.isorter.column = sorter.field
        this.isorter.order = 'ascend' === sorter.order ? 'asc' : 'desc'
      }
      this.ipagination = pagination
      this.loadData()
    },
    handleSubmit() {
      this.$emit('selectionRows', this.selectSource)
      this.searchReset(0)
      this.close()
    },

    async searchQuery() {
      this.ipagination.current = 1
      this.loading = true
      let params = this.getQueryParams()//查询条件
      await getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.selectSource = []
          this.selectedRowKeys = []
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })
    }
  }
}
</script>
  
<style scoped>
.ant-table-tbody .ant-table-row td {
  padding-top: 10px;
  padding-bottom: 10px;
}

#components-layout-demo-custom-trigger .trigger {
  font-size: 18px;
  line-height: 64px;
  padding: 0 24px;
  cursor: pointer;
  transition: color 0.3s;
}
</style>